@@ -23,8 +23,7 @@ except ImportError:
         import sip
 
         sip.setapi('QVariant', 2)
-    from PyQt4.QtGui import *
-    from PyQt4.QtCore import *
+
 
 # Add internal libs
 from libs.constants import *
